import torch
import torch.nn as nn
import torch.nn.functional as F
from collections import OrderedDict


def interpolate(t, sz):
    sz = sz.tolist() if torch.is_tensor(sz) else sz
    return F.interpolate(t, sz, mode='bilinear', align_corners=False) if t.shape[-2:] != sz else t


class InterpCat(nn.Module):
    def __init__(self):
        super().__init__()

    def forward(self, input):
        if isinstance(input, (dict, OrderedDict)):
            input = list(input.values())

        output_shape = None
        for x in input:
            if output_shape is None or output_shape[0] > x.shape[-2]:
                output_shape = x.shape[-2:]

        return torch.cat([interpolate(x, output_shape) for x in input], dim=-3)