function benchmark_tracker_wrapper(tracker_name, runfile_name, vot_comm_path, do_cleanup)

if nargin < 4
    do_cleanup = true;
end

% *************************************************************
% VOT: Always call exit command at the end to terminate Matlab!
% *************************************************************
if do_cleanup
    cleanup = onCleanup(@() exit() );
else
    [pathstr, ~, ~] = fileparts(mfilename('fullpath'));
    cd_ind = strfind(pathstr, filesep());
    pathstr = pathstr(1:cd_ind(end)-1);
    cleanup = onCleanup(@() cd(pathstr));
end

try
    % *************************************************************
    % VOT: Set random seed to a different value every time.
    % *************************************************************
    RandStream.setGlobalStream(RandStream('mt19937ar', 'Seed', sum(clock)));
    
    seq.format = 'vot';    
    [pathstr, name, ext] = fileparts(mfilename('fullpath'));
    
    cd_ind = strfind(pathstr, filesep());
    pathstr = pathstr(1:cd_ind(end-1)-1);
    disp(['pytracking_wrapper(seq, ''', tracker_name, ''', ''', runfile_name, ''', ''', vot_comm_path,''');']);
    eval(['pytracking_wrapper(seq, ''', tracker_name, ''', ''', runfile_name, ''', ''', vot_comm_path, ''');']);
catch err
    disp('Crashed');
    
    % Clean up
    init_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_init.txt'];
    fname = [vot_comm_path, tracker_name, '_', parameter_name, '.txt'];
    frame_status_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_frame_status.txt'];
    output_status_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_output_status.txt'];
    result_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_output.txt'];
    delete(result_fname);
    delete(init_fname);
    delete(frame_status_fname);
    delete(output_status_fname);
    
    fid = fopen(fname, 'w');
    fprintf(fid, '');
    fclose(fid);
    
    % Write status
    fid = fopen(frame_status_fname, 'w');
    fclose(fid);
    
    % Wait for acknowledgement from python
    while true
        if exist(output_status_fname, 'file') == 2
            pause(0.001);
            delete(result_fname);
            delete(output_status_fname);
            break;
        else
            pause(0.001);
        end
    end
    
    [wrapper_pathstr, ~, ~] = fileparts(mfilename('fullpath'));
    cd_ind = strfind(wrapper_pathstr, filesep());
    VOT_path = wrapper_pathstr(1:cd_ind(end));
    
    error_report_path = [VOT_path 'error_reports/'];
    if ~exist(error_report_path, 'dir')
        mkdir(error_report_path);
    end
    
    report_file_name = [error_report_path tracker_name '_' runfile_name datestr(now,'_yymmdd_HHMM') '.mat'];
    save(report_file_name, 'err')
    rethrow(err);
end

