function pytracking_wrapper(seq, tracker_name, parameter_name, vot_comm_path)

init_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_init.txt'];
init_status_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_init_status.txt'];
frame_fname = [vot_comm_path, tracker_name, '_', parameter_name, '.txt'];
frame_status_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_frame_status.txt'];
output_status_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_output_status.txt'];
output_fname = [vot_comm_path, tracker_name, '_', parameter_name, '_output.txt'];

delete(output_fname);
delete(init_status_fname);
delete(frame_fname);
delete(init_fname);
delete(frame_status_fname);
delete(output_status_fname);

% Kill any existing python tracker
fid = fopen(frame_fname, 'w');
fprintf(fid, '');
fclose(fid);

% Write status
fid = fopen(frame_status_fname, 'w');
fclose(fid);

% Wait for acknowledgement from python
pause(1);
if exist(output_status_fname, 'file') == 2
    pause(0.001);
    delete(output_fname);
    delete(output_status_fname);
end

delete(frame_fname);
delete(frame_status_fname);

% Start tracking
[seq.handle, init_image_file, init_region] = vot('polygon');
tic
init_image_file = init_image_file{1};
if isempty(init_image_file)
    init_image = [];
    fid = fopen(init_fname, 'w');
    fprintf(fid, '');
    fclose(fid);
    
    % Write status
    fid = fopen(init_status_fname, 'w');
    fclose(fid);
    
    % Wait for acknowledgement from python
    while true
        if exist(output_status_fname, 'file') == 2
            pause(0.001);
            delete(output_fname);
            delete(output_status_fname);
            return;
        else
            pause(0.001);
        end
    end
end

% Write filename
fid = fopen(init_fname, 'w');
if numel(init_region) == 4
    sprintf('%s\n%f %f %f %f', init_image_file, init_region);
    fprintf(fid, '%s\n%f %f %f %f', init_image_file, init_region);
elseif numel(init_region) == 8
    sprintf('%s\n%f %f %f %f %f %f %f %f', init_image_file, init_region);
    fprintf(fid, '%s\n%f %f %f %f %f %f %f %f', init_image_file, init_region);
else
    % Not sure why this is there
    while true
        disp('Error: Weird anno');
        disp(init_region)
        pause(1); 
    end
end

fclose(fid);

pause(0.001); 
% Write status
fid = fopen(init_status_fname, 'w');
fclose(fid);

% Wait for output
while true
    if exist(output_status_fname, 'file') == 2
        disp('Received ack from python');
        pause(0.001);
        delete(output_fname);
        delete(output_status_fname);
        break;
    else
        pause(0.001);
    end
end

while true
    [seq.handle, image_file] = seq.handle.frame(seq.handle);
    tic
    image_file = image_file{1};
    if isempty(image_file)
        fid = fopen(frame_fname, 'w');
        fprintf(fid, '');
        fclose(fid);
        
        % Write status
        fid = fopen(frame_status_fname, 'w');
        fclose(fid);
        
        % Wait for acknowledgement from python
        while true
            if exist(output_status_fname, 'file') == 2
                pause(0.001);
                delete(output_fname);
                delete(output_status_fname);
                return;
            else
                pause(0.001);
            end
        end
    else
        fid = fopen(frame_fname, 'w');
        fprintf(fid, '%s', image_file);
        fclose(fid);
        
        % Write status
        fid = fopen(frame_status_fname, 'w');
        fclose(fid);
    end
    
    % Wait for output
    while true
        if exist(output_status_fname, 'file') == 2
            pause(0.001);
            bb = dlmread(output_fname);
            delete(output_fname);
            delete(output_status_fname);
            break;
        else
            pause(0.001);
        end
    end
    % Report result
    x1 = bb(1);
    y1 = bb(2);
    x2 = x1 + bb(3);
    y2 = y1 + bb(4);
    result_box = (double([x1 y1 x2 y1 x2 y2 x1 y2]));
    if any(isnan(result_box) | isinf(result_box))
        disp('Illegal values in the result');
        error('Illegal values in the result.')
    end
    
    confidence = 1;
    seq.handle = seq.handle.report(seq.handle, result_box);
end

